@@ -3,13 +3,12 @@
 // kvm screensaver
 //
 
-#ifndef __KVM_H__
-#define __KVM_H__
+#ifndef KVM_H
+#define KVM_H
 
 #include <qtimer.h>
-#include <qptrlist.h>
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <kscreensaver.h>
 
 extern "C" {
@@ -52,17 +51,13 @@ public:
 	void setRefreshTimeout( const int refreshTimeout );
 
 protected:
-	void blank();
 	void readSettings();
         int getRandom( const int max_value );
         void modifyArea( const int op );
-
-protected slots:
-	void slotTimeout();
+        void paintEvent(QPaintEvent *event);
 
 protected:
 	QTimer      timer;
-	int         colorContext;
 
 	int         speed;
 	m_state*    pool_state;
@@ -71,11 +66,11 @@ protected:
 };
 
 
-class kVmSetup : public KDialogBase
+class kVmSetup : public KDialog
 {
 	Q_OBJECT
 public:
-	kVmSetup( QWidget *parent = NULL, const char *name = NULL );
+	kVmSetup( QWidget *parent = NULL );
     ~kVmSetup();
 protected:
 	void readSettings();
