@@ -51,6 +51,7 @@ USING_PART_OF_NAMESPACE_EIGEN
 #include "sspreviewarea.h"
 
 #include "pendulum.h"           // own interfaces
+#include <kcolordialog.h>
 #include "pendulum.moc"
 
 #define KPENDULUM_VERSION "2.0"
@@ -401,10 +402,11 @@ KPendulumSaver::KPendulumSaver(WId id) :
    // no need to set our parent widget's background here, the GL widget sets its
    // own background color
 
-   readSettings();              // read global settings into pars
 
    m_glArea = new PendulumGLWidget(); // create gl widget w/o parent
    m_glArea->setEyePhi(sm_eyePhiDefault);
+   readSettings();              // read global settings into pars
+
 
    // init m_glArea with read settings, construct and init m_solver
    initData();
@@ -787,6 +789,7 @@ KPendulumSetup::KPendulumSetup(QWidget* parent)
    QPalette palette;
    palette.setColor(m_preview->backgroundRole(), Qt::black);
    m_preview->setPalette(palette);
+   m_preview->setAutoFillBackground(true);
    m_preview->show();    // otherwise saver does not get correct size
 
    // create saver and give it the WinID of the preview area
@@ -822,6 +825,7 @@ KPendulumSetup::KPendulumSetup(QWidget* parent)
            m_saver,   SLOT(resizeGlArea(QResizeEvent*)));
 
    connect(m_okButton,       SIGNAL(clicked()),         this, SLOT(okButtonClickedSlot()));
+   connect( m_cancelButton,  SIGNAL(clicked()),         this, SLOT(reject() ) );
    connect(m_aboutButton,    SIGNAL(clicked()),         this, SLOT(aboutButtonClickedSlot()));
 
    connect(m_lEdit,          SIGNAL(lostFocus()),       this, SLOT(lEditLostFocusSlot()));
@@ -926,37 +930,44 @@ void KPendulumSetup::persChangeEnteredSlot(int t)
 
 void KPendulumSetup::barColorButtonClickedSlot(void)
 {
-   QColor color = QColorDialog::getColor(
-      m_saver->barColor(), this);
-   if (color.isValid())
-   {
-      m_saver->setBarColor(color);
-      QPalette palette;
-      palette.setColor(m_barColorButton->backgroundRole(), color);
-      m_barColorButton->setPalette(palette);
-   }
+    QColor color = m_saver->barColor();
+    if ( KColorDialog::getColor( color, this) )
+    {
+        if (color.isValid())
+        {
+            m_saver->setBarColor(color);
+            QPalette palette;
+            palette.setColor(m_barColorButton->backgroundRole(), color);
+            m_barColorButton->setPalette(palette);
+        }
+    }
 }
+
 void KPendulumSetup::m1ColorButtonClickedSlot(void)
 {
-   QColor color = QColorDialog::getColor(
-      m_saver->m1Color(), this);
-   if (color.isValid())
-   {
-      m_saver->setM1Color(color);
-      QPalette palette;
-      palette.setColor(m_m1ColorButton->backgroundRole(), color);
-      m_m1ColorButton->setPalette(palette);
-   }
+    QColor color =m_saver->m1Color();
+    if ( KColorDialog::getColor( color, this) )
+    {
+        if (color.isValid())
+        {
+            m_saver->setM1Color(color);
+            QPalette palette;
+            palette.setColor(m_m1ColorButton->backgroundRole(), color);
+            m_m1ColorButton->setPalette(palette);
+        }
+    }
 }
 void KPendulumSetup::m2ColorButtonClickedSlot(void)
 {
-   QColor color = QColorDialog::getColor(
-      m_saver->m2Color(), this);
-   if (color.isValid())
-   {
-      m_saver->setM2Color(color);
-      QPalette palette;
-      palette.setColor(m_m2ColorButton->backgroundRole(), color);
-      m_m2ColorButton->setPalette(palette);
-   }
+    QColor color = m_saver->m2Color();
+    if ( KColorDialog::getColor( color, this) )
+    {
+        if (color.isValid())
+        {
+            m_saver->setM2Color(color);
+            QPalette palette;
+            palette.setColor(m_m2ColorButton->backgroundRole(), color);
+            m_m2ColorButton->setPalette(palette);
+        }
+    }
 }
